import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';

// this is required to hook vega and vega-lite together
vl.register(vega, vegaLite, {
  view: { renderer: 'svg' }, // set default renderer (ex. 'canvas' renders plain image, 'svg' renders vector image)
  init: view => { view.tooltip(new Handler().call); } // logic that makes the tooltips work
});

const run = async () => {
  // extends our visualization definition
  const marks = viz
  	.data(await getData())  // provide data
    .width(window.innerWidth)  // set width & height to be the size of our window
  	.height(window.innerHeight)
  	.autosize({ type: 'fit', contains: 'padding' }) // making sure visualization fits properly inside the box we gave
  	.config(config);  // customizes appearance of the visualization
  
  document.body.appendChild(await marks.render());
  // .render() method is asynchronous so it returns a promise. We need to await its response to get resolved
  // it returns a DOM element: a <div> that contains a <svg> inside of it
};
run();
